Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Database.SigSourceinclude Sihl_core.Container.Service.Sigval lifecycle : Sihl_core.Container.Lifecycle.tval raise_error : ('a, Caqti_error.t) Result.t -> 'araise_error err raises a printable caqti error err .
val fetch_pool : unit -> (Caqti_lwt.connection, Caqti_error.t) Caqti_lwt.Pool.tfetch_pool () returns the connection pool.
val query : (Caqti_lwt.connection -> 'a Lwt.t) -> 'a Lwt.tquery ctx f runs the query f on the connection pool and returns the result. If the query fails the Lwt.t fails as well.
val transaction : (Caqti_lwt.connection -> 'a Lwt.t) -> 'a Lwt.ttransaction ctx f runs the query f on the connection pool in a transaction and returns the result. If the query fails the Lwt.t fails as well and the transaction gets rolled back. If the database driver doesn't support transactions, transaction gracefully becomes query.
val register : unit -> Sihl_core.Container.Service.t