Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
database.ml1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21module type Sig = sig include Sihl_core.Container.Service.Sig (** [raise_error err] raises a printable caqti error [err] .*) val raise_error : ('a, Caqti_error.t) Result.t -> 'a (** [fetch_pool ()] returns the connection pool. *) val fetch_pool : unit -> (Caqti_lwt.connection, Caqti_error.t) Caqti_lwt.Pool.t (** [query ctx f] runs the query [f] on the connection pool and returns the result. If the query fails the Lwt.t fails as well. *) val query : (Caqti_lwt.connection -> 'a Lwt.t) -> 'a Lwt.t (** [transaction ctx f] runs the query [f] on the connection pool in a transaction and returns the result. If the query fails the Lwt.t fails as well and the transaction gets rolled back. If the database driver doesn't support transactions, [transaction] gracefully becomes [query]. *) val transaction : (Caqti_lwt.connection -> 'a Lwt.t) -> 'a Lwt.t val register : unit -> Sihl_core.Container.Service.t end